ErrorKind

Enum ErrorKind 

pub enum ErrorKind {
Show 24 variants NotFound, PermissionDenied, ConnectionRefused, ConnectionReset, ConnectionAborted, NotConnected, AddrInUse, AddrNotAvailable, BrokenPipe, AlreadyExists, WouldBlock, InvalidInput, InvalidData, TimedOut, WriteZero, Interrupted, Other, UnexpectedEof, Unsupported, OutOfMemory, Loop, TaskCancelled, TaskPanicked, Unknown,
}
All possible kinds of errors that can be returned

Variants



NotFound

An entity was not found, often a file



PermissionDenied

The operation lacked the necessary privileges to complete



ConnectionRefused

The connection was refused by the remote server



ConnectionReset

The connection was reset by the remote server



ConnectionAborted

The connection was aborted (terminated) by the remote server



NotConnected

The network operation failed because it was not connected yet



AddrInUse

A socket address could not be bound because the address is already in use elsewhere



AddrNotAvailable

A nonexistent interface was requested or the requested address was not local



BrokenPipe

The operation failed because a pipe was closed



AlreadyExists

An entity already exists, often a file



WouldBlock

The operation needs to block to complete, but the blocking operation was requested to not occur



InvalidInput

A parameter was incorrect



InvalidData

Data not valid for the operation were encountered



TimedOut

The I/O operation’s timeout expired, causing it to be cancelled



WriteZero

An error returned when an operation could not be completed because a call to write returned Ok(0)



Interrupted

This operation was interrupted



Other

Any I/O error not part of this list



UnexpectedEof

An error returned when an operation could not be completed because an “end of file” was reached prematurely



Unsupported

This operation is unsupported on this platform



OutOfMemory

An operation could not be completed, because it failed to allocate enough memory



Loop

When a loop is encountered when walking a directory



TaskCancelled

When a task is cancelled



TaskPanicked

When a task panics



Unknown

Catchall for an error that has no specific type