WindowsMetadata

Struct WindowsMetadata 

pub struct WindowsMetadata {
Show 15 fields pub archive: bool, pub compressed: bool, pub encrypted: bool, pub hidden: bool, pub integrity_stream: bool, pub normal: bool, pub not_content_indexed: bool, pub no_scrub_data: bool, pub offline: bool, pub recall_on_data_access: bool, pub recall_on_open: bool, pub reparse_point: bool, pub sparse_file: bool, pub system: bool, pub temporary: bool,
}
Represents windows-specific metadata about some path on a remote machine

Fields

archive: bool

Represents whether or not a file or directory is an archive

compressed: bool

Represents whether or not a file or directory is compressed

encrypted: bool

Represents whether or not the file or directory is encrypted

hidden: bool

Represents whether or not a file or directory is hidden

integrity_stream: bool

Represents whether or not a directory or user data stream is configured with integrity

normal: bool

Represents whether or not a file does not have other attributes set

not_content_indexed: bool

Represents whether or not a file or directory is not to be indexed by content indexing service

no_scrub_data: bool

Represents whether or not a user data stream is not to be read by the background data integrity scanner

offline: bool

Represents whether or not the data of a file is not available immediately

recall_on_data_access: bool

Represents whether or not a file or directory is not fully present locally

recall_on_open: bool

Represents whether or not a file or directory has no physical representation on the local system (is virtual)

reparse_point: bool

Represents whether or not a file or directory has an associated reparse point, or a file is a symbolic link

sparse_file: bool

Represents whether or not a file is a sparse file

system: bool

Represents whether or not a file or directory is used partially or exclusively by the operating system

temporary: bool

Represents whether or not a file is being used for temporary storage